==> haskell-descriptive-0.9.4-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-HrvO2uZxVm7HYStNk0R1TB
key: descriptive-0.9.4-HrvO2uZxVm7HYStNk0R1TB
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: 7aefa0866d03b5f3116910b65a94a0bf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-HrvO2uZxVm7HYStNk0R1TB
depends:
    aeson-0.11.2.0-31ZI7bFuFz27ynqHifCKlM base-4.9.0.0
    bifunctors-5.4.1-EBkHk3WI7L87dRJGvKP176 containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.4-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-Le7UydCGJ38H2rxEjocgtE
key: descriptive-0.9.4-Le7UydCGJ38H2rxEjocgtE
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.Options Descriptive.JSON
hidden-modules: Descriptive.Internal
abi: 7fd7e956dbed1c4af8616a3ef94bc955
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/descriptive-0.9.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-Le7UydCGJ38H2rxEjocgtE
depends:
    aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M base-4.9.0.0
    bifunctors-5.4.1-EBkHk3WI7L87dRJGvKP176 containers-0.5.7.1
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
